==> libosl_0.5.0.orig.tar.gz: libosl_0.5.0.orig/doc/html/search/classes_61.js <==
var searchData=
[
  ['accuratecenter',['AccurateCenter',['../classAccurateCenter.html',1,'']]],
  ['addeffect',['AddEffect',['../classosl_1_1move__generator_1_1AddEffect.html',1,'osl::move_generator']]],
  ['addeffect8',['AddEffect8',['../classosl_1_1move__generator_1_1AddEffect8.html',1,'osl::move_generator']]],
  ['addeffect8defense',['AddEffect8Defense',['../structosl_1_1move__generator_1_1AddEffect8Defense.html',1,'osl::move_generator']]],
  ['addeffect8table',['AddEffect8Table',['../classosl_1_1move__generator_1_1addeffect8_1_1AddEffect8Table.html',1,'osl::move_generator::addeffect8']]],
  ['addeffectlong',['AddEffectLong',['../structosl_1_1move__generator_1_1AddEffectLong.html',1,'osl::move_generator']]],
  ['addeffectlong',['AddEffectLong',['../classosl_1_1move__probability_1_1AddEffectLong.html',1,'osl::move_probability']]],
  ['addeffectshort',['AddEffectShort',['../structosl_1_1move__generator_1_1AddEffectShort.html',1,'osl::move_generator']]],
  ['addeffecttable',['AddEffectTable',['../classosl_1_1move__generator_1_1AddEffectTable.html',1,'osl::move_generator']]],
  ['addeffectwitheffect',['AddEffectWithEffect',['../classosl_1_1move__generator_1_1AddEffectWithEffect.html',1,'osl::move_generator']]],
  ['additionaleffect',['AdditionalEffect',['../structosl_1_1effect__util_1_1AdditionalEffect.html',1,'osl::effect_util']]],
  ['additionallance',['AdditionalLance',['../structosl_1_1move__generator_1_1AdditionalLance.html',1,'osl::move_generator']]],
  ['additionalorshadow',['AdditionalOrShadow',['../structosl_1_1effect__util_1_1AdditionalOrShadow.html',1,'osl::effect_util']]],
  ['addmaskaction',['AddMaskAction',['../classosl_1_1effect_1_1AddMaskAction.html',1,'osl::effect']]],
  ['align16new',['Align16New',['../structosl_1_1misc_1_1Align16New.html',1,'osl::misc']]],
  ['allgold',['AllGold',['../classosl_1_1eval_1_1ml_1_1AllGold.html',1,'osl::eval::ml']]],
  ['allmajor',['AllMajor',['../classosl_1_1eval_1_1ml_1_1AllMajor.html',1,'osl::eval::ml']]],
  ['allmoves',['AllMoves',['../classosl_1_1move__generator_1_1AllMoves.html',1,'osl::move_generator']]],
  ['allpromote',['AllPromote',['../classosl_1_1move__generator_1_1promote_1_1AllPromote.html',1,'osl::move_generator::promote']]],
  ['allpromotedir',['AllPromoteDir',['../classosl_1_1move__generator_1_1promote_1_1AllPromoteDir.html',1,'osl::move_generator::promote']]],
  ['alphabeta2',['AlphaBeta2',['../classosl_1_1search_1_1AlphaBeta2.html',1,'osl::search']]],
  ['alphabeta2common',['AlphaBeta2Common',['../structosl_1_1search_1_1AlphaBeta2Common.html',1,'osl::search']]],
  ['alphabeta2openmidendingevalplayer',['AlphaBeta2OpenMidEndingEvalPlayer',['../classosl_1_1game__playing_1_1AlphaBeta2OpenMidEndingEvalPlayer.html',1,'osl::game_playing']]],
  ['alphabeta2progressevalplayer',['AlphaBeta2ProgressEvalPlayer',['../classosl_1_1game__playing_1_1AlphaBeta2ProgressEvalPlayer.html',1,'osl::game_playing']]],
  ['alphabeta2sharedroot',['AlphaBeta2SharedRoot',['../structosl_1_1search_1_1AlphaBeta2SharedRoot.html',1,'osl::search']]],
  ['alphabeta2tree',['AlphaBeta2Tree',['../classosl_1_1search_1_1AlphaBeta2Tree.html',1,'osl::search']]],
  ['alphabeta2window',['AlphaBeta2Window',['../classosl_1_1search_1_1AlphaBeta2Window.html',1,'osl::search']]],
  ['alphabeta3',['AlphaBeta3',['../classosl_1_1search_1_1AlphaBeta3.html',1,'osl::search']]],
  ['alphabeta3openmidendingevalplayer',['AlphaBeta3OpenMidEndingEvalPlayer',['../classosl_1_1game__playing_1_1AlphaBeta3OpenMidEndingEvalPlayer.html',1,'osl::game_playing']]],
  ['alphabetawindow',['AlphaBetaWindow',['../structosl_1_1search_1_1AlphaBetaWindow.html',1,'osl::search']]],
  ['alphabetawindowutil',['AlphaBetaWindowUtil',['../structosl_1_1search_1_1AlphaBetaWindowUtil.html',1,'osl::search']]],
  ['alwaysmove',['AlwaysMove',['../classosl_1_1effect__action_1_1AlwaysMove.html',1,'osl::effect_action']]],
  ['anagumaempty',['AnagumaEmpty',['../classosl_1_1eval_1_1ml_1_1AnagumaEmpty.html',1,'osl::eval::ml']]],
  ['analysesresult',['AnalysesResult',['../structosl_1_1annotate_1_1AnalysesResult.html',1,'osl::annotate']]],
  ['analyzer',['Analyzer',['../classAnalyzer.html',1,'']]],
  ['analyzer',['Analyzer',['../classosl_1_1annotate_1_1Analyzer.html',1,'osl::annotate']]],
  ['applydoundocapturemove_3c_20p_2c_20boardbiteffect_3c_20basestate_20_3e_20_3e',['ApplyDoUndoCaptureMove< P, BoardBitEffect< BaseState > >',['../structosl_1_1effect_1_1ApplyDoUndoCaptureMove_3_01P_00_01BoardBitEffect_3_01BaseState_01_4_01_4.html',1,'osl::effect']]],
  ['applydoundocapturemove_3c_20p_2c_20signatureeffect_3c_20basestate_20_3e_20_3e',['ApplyDoUndoCaptureMove< P, SignatureEffect< BaseState > >',['../structosl_1_1effect_1_1ApplyDoUndoCaptureMove_3_01P_00_01SignatureEffect_3_01BaseState_01_4_01_4.html',1,'osl::effect']]],
  ['applydoundodropmove_3c_20p_2c_20boardbiteffect_3c_20basestate_20_3e_20_3e',['ApplyDoUndoDropMove< P, BoardBitEffect< BaseState > >',['../structosl_1_1effect_1_1ApplyDoUndoDropMove_3_01P_00_01BoardBitEffect_3_01BaseState_01_4_01_4.html',1,'osl::effect']]],
  ['applydoundodropmove_3c_20p_2c_20signatureeffect_3c_20basestate_20_3e_20_3e',['ApplyDoUndoDropMove< P, SignatureEffect< BaseState > >',['../structosl_1_1effect_1_1ApplyDoUndoDropMove_3_01P_00_01SignatureEffect_3_01BaseState_01_4_01_4.html',1,'osl::effect']]],
  ['applydoundosimplemove_3c_20p_2c_20boardbiteffect_3c_20basestate_20_3e_20_3e',['ApplyDoUndoSimpleMove< P, BoardBitEffect< BaseState > >',['../structosl_1_1effect_1_1ApplyDoUndoSimpleMove_3_01P_00_01BoardBitEffect_3_01BaseState_01_4_01_4.html',1,'osl::effect']]],
  ['applydoundosimplemove_3c_20p_2c_20signatureeffect_3c_20basestate_20_3e_20_3e',['ApplyDoUndoSimpleMove< P, SignatureEffect< BaseState > >',['../structosl_1_1effect_1_1ApplyDoUndoSimpleMove_3_01P_00_01SignatureEffect_3_01BaseState_01_4_01_4.html',1,'osl::effect']]],
  ['array',['Array',['../structosl_1_1misc_1_1FixedCapacityVector_1_1Array.html',1,'osl::misc::FixedCapacityVector']]],
  ['atomiccounter',['AtomicCounter',['../classosl_1_1misc_1_1AtomicCounter.html',1,'osl::misc']]],
  ['attackdefencearoundking',['AttackDefenceAroundKing',['../structosl_1_1move__classifier_1_1AttackDefenceAroundKing.html',1,'osl::move_classifier']]],
  ['attackdefense',['AttackDefense',['../classosl_1_1eval_1_1endgame_1_1AttackDefense.html',1,'osl::eval::endgame']]],
  ['attackfromopposingsliders',['AttackFromOpposingSliders',['../classosl_1_1move__probability_1_1AttackFromOpposingSliders.html',1,'osl::move_probability']]],
  ['attackhelper',['AttackHelper',['../classOracleProverLight_1_1AttackHelper.html',1,'osl::ntesuki::OracleProverLight']]],
  ['attackhelper',['AttackHelper',['../classosl_1_1ntesuki_1_1NtesukiSearcher_1_1AttackHelper.html',1,'osl::ntesuki::NtesukiSearcher']]],
  ['attackhelperdisproof',['AttackHelperDisproof',['../classNtesukiSimulationSearcher_1_1AttackHelperDisproof.html',1,'osl::ntesuki::NtesukiSimulationSearcher']]],
  ['attackhelperproof',['AttackHelperProof',['../classNtesukiSimulationSearcher_1_1AttackHelperProof.html',1,'osl::ntesuki::NtesukiSimulationSearcher']]],
  ['attackking',['AttackKing',['../classosl_1_1eval_1_1endgame_1_1AttackKing.html',1,'osl::eval::endgame']]],
  ['attackking8',['AttackKing8',['../classosl_1_1rating_1_1AttackKing8.html',1,'osl::rating']]],
  ['attackking8group',['AttackKing8Group',['../structosl_1_1rating_1_1AttackKing8Group.html',1,'osl::rating']]],
  ['attackking8long',['AttackKing8Long',['../classosl_1_1move__probability_1_1AttackKing8Long.html',1,'osl::move_probability']]],
  ['attackmajorsinbase',['AttackMajorsInBase',['../classosl_1_1eval_1_1ml_1_1AttackMajorsInBase.html',1,'osl::eval::ml']]],
  ['attacktoopposingsliders',['AttackToOpposingSliders',['../classosl_1_1move__probability_1_1AttackToOpposingSliders.html',1,'osl::move_probability']]],
  ['attacktopinned',['AttackToPinned',['../classosl_1_1move__generator_1_1AttackToPinned.html',1,'osl::move_generator']]],
  ['average',['Average',['../classosl_1_1stat_1_1Average.html',1,'osl::stat']]]
];

==> libosl_0.6.0.orig.tar.gz: libosl_0.6.0.orig/doc/html/search/classes_61.js <==
var searchData=
[
  ['accuratecenter',['AccurateCenter',['../classAccurateCenter.html',1,'']]],
  ['addeffect',['AddEffect',['../classosl_1_1move__generator_1_1AddEffect.html',1,'osl::move_generator']]],
  ['addeffect8',['AddEffect8',['../classosl_1_1move__generator_1_1AddEffect8.html',1,'osl::move_generator']]],
  ['addeffect8defense',['AddEffect8Defense',['../structosl_1_1move__generator_1_1AddEffect8Defense.html',1,'osl::move_generator']]],
  ['addeffect8table',['AddEffect8Table',['../classosl_1_1move__generator_1_1addeffect8_1_1AddEffect8Table.html',1,'osl::move_generator::addeffect8']]],
  ['addeffectlong',['AddEffectLong',['../structosl_1_1move__generator_1_1AddEffectLong.html',1,'osl::move_generator']]],
  ['addeffectlong',['AddEffectLong',['../classosl_1_1move__probability_1_1AddEffectLong.html',1,'osl::move_probability']]],
  ['addeffectshort',['AddEffectShort',['../structosl_1_1move__generator_1_1AddEffectShort.html',1,'osl::move_generator']]],
  ['addeffecttable',['AddEffectTable',['../classosl_1_1move__generator_1_1AddEffectTable.html',1,'osl::move_generator']]],
  ['addeffectwitheffect',['AddEffectWithEffect',['../classosl_1_1move__generator_1_1AddEffectWithEffect.html',1,'osl::move_generator']]],
  ['additionaleffect',['AdditionalEffect',['../structosl_1_1effect__util_1_1AdditionalEffect.html',1,'osl::effect_util']]],
  ['additionallance',['AdditionalLance',['../structosl_1_1move__generator_1_1AdditionalLance.html',1,'osl::move_generator']]],
  ['additionalorshadow',['AdditionalOrShadow',['../structosl_1_1effect__util_1_1AdditionalOrShadow.html',1,'osl::effect_util']]],
  ['addmaskaction',['AddMaskAction',['../classosl_1_1effect_1_1AddMaskAction.html',1,'osl::effect']]],
  ['align16new',['Align16New',['../structosl_1_1misc_1_1Align16New.html',1,'osl::misc']]],
  ['allgold',['AllGold',['../classosl_1_1eval_1_1ml_1_1AllGold.html',1,'osl::eval::ml']]],
  ['allmajor',['AllMajor',['../classosl_1_1eval_1_1ml_1_1AllMajor.html',1,'osl::eval::ml']]],
  ['allmoves',['AllMoves',['../classosl_1_1move__generator_1_1AllMoves.html',1,'osl::move_generator']]],
  ['allpromote',['AllPromote',['../classosl_1_1move__generator_1_1promote_1_1AllPromote.html',1,'osl::move_generator::promote']]],
  ['allpromotedir',['AllPromoteDir',['../classosl_1_1move__generator_1_1promote_1_1AllPromoteDir.html',1,'osl::move_generator::promote']]],
  ['alphabeta2',['AlphaBeta2',['../classosl_1_1search_1_1AlphaBeta2.html',1,'osl::search']]],
  ['alphabeta2common',['AlphaBeta2Common',['../structosl_1_1search_1_1AlphaBeta2Common.html',1,'osl::search']]],
  ['alphabeta2openmidendingevalplayer',['AlphaBeta2OpenMidEndingEvalPlayer',['../classosl_1_1game__playing_1_1AlphaBeta2OpenMidEndingEvalPlayer.html',1,'osl::game_playing']]],
  ['alphabeta2parallel',['AlphaBeta2Parallel',['../structosl_1_1search_1_1AlphaBeta2Parallel.html',1,'osl::search']]],
  ['alphabeta2progressevalplayer',['AlphaBeta2ProgressEvalPlayer',['../classosl_1_1game__playing_1_1AlphaBeta2ProgressEvalPlayer.html',1,'osl::game_playing']]],
  ['alphabeta2sharedroot',['AlphaBeta2SharedRoot',['../structosl_1_1search_1_1AlphaBeta2SharedRoot.html',1,'osl::search']]],
  ['alphabeta2tree',['AlphaBeta2Tree',['../classosl_1_1search_1_1AlphaBeta2Tree.html',1,'osl::search']]],
  ['alphabeta2window',['AlphaBeta2Window',['../classosl_1_1search_1_1AlphaBeta2Window.html',1,'osl::search']]],
  ['alphabeta3',['AlphaBeta3',['../classosl_1_1search_1_1AlphaBeta3.html',1,'osl::search']]],
  ['alphabeta3openmidendingevalplayer',['AlphaBeta3OpenMidEndingEvalPlayer',['../classosl_1_1game__playing_1_1AlphaBeta3OpenMidEndingEvalPlayer.html',1,'osl::game_playing']]],
  ['alphabeta4',['AlphaBeta4',['../classosl_1_1search4_1_1AlphaBeta4.html',1,'osl::search4']]],
  ['alphabeta4player',['AlphaBeta4Player',['../classosl_1_1game__playing_1_1AlphaBeta4Player.html',1,'osl::game_playing']]],
  ['alphabetawindow',['AlphaBetaWindow',['../structosl_1_1search_1_1AlphaBetaWindow.html',1,'osl::search']]],
  ['alphabetawindowutil',['AlphaBetaWindowUtil',['../structosl_1_1search_1_1AlphaBetaWindowUtil.html',1,'osl::search']]],
  ['alwaysmove',['AlwaysMove',['../classosl_1_1effect__action_1_1AlwaysMove.html',1,'osl::effect_action']]],
  ['anagumaempty',['AnagumaEmpty',['../classosl_1_1eval_1_1ml_1_1AnagumaEmpty.html',1,'osl::eval::ml']]],
  ['analysesresult',['AnalysesResult',['../structosl_1_1annotate_1_1AnalysesResult.html',1,'osl::annotate']]],
  ['analyzer',['Analyzer',['../classAnalyzer.html',1,'']]],
  ['analyzer',['Analyzer',['../classosl_1_1annotate_1_1Analyzer.html',1,'osl::annotate']]],
  ['applydoundocapturemove',['ApplyDoUndoCaptureMove',['../structosl_1_1effect_1_1ApplyDoUndoCaptureMove.html',1,'osl::effect']]],
  ['applydoundocapturemove_3c_20p_2c_20boardbiteffect_3c_20basestate_20_3e_20_3e',['ApplyDoUndoCaptureMove&lt; P, BoardBitEffect&lt; BaseState &gt; &gt;',['../structosl_1_1effect_1_1ApplyDoUndoCaptureMove_3_01P_00_01BoardBitEffect_3_01BaseState_01_4_01_4.html',1,'osl::effect']]],
  ['applydoundocapturemove_3c_20p_2c_20signatureeffect_3c_20basestate_20_3e_20_3e',['ApplyDoUndoCaptureMove&lt; P, SignatureEffect&lt; BaseState &gt; &gt;',['../structosl_1_1effect_1_1ApplyDoUndoCaptureMove_3_01P_00_01SignatureEffect_3_01BaseState_01_4_01_4.html',1,'osl::effect']]],
  ['applydoundodropmove',['ApplyDoUndoDropMove',['../structosl_1_1effect_1_1ApplyDoUndoDropMove.html',1,'osl::effect']]],
  ['applydoundodropmove_3c_20p_2c_20boardbiteffect_3c_20basestate_20_3e_20_3e',['ApplyDoUndoDropMove&lt; P, BoardBitEffect&lt; BaseState &gt; &gt;',['../structosl_1_1effect_1_1ApplyDoUndoDropMove_3_01P_00_01BoardBitEffect_3_01BaseState_01_4_01_4.html',1,'osl::effect']]],
  ['applydoundodropmove_3c_20p_2c_20signatureeffect_3c_20basestate_20_3e_20_3e',['ApplyDoUndoDropMove&lt; P, SignatureEffect&lt; BaseState &gt; &gt;',['../structosl_1_1effect_1_1ApplyDoUndoDropMove_3_01P_00_01SignatureEffect_3_01BaseState_01_4_01_4.html',1,'osl::effect']]],
  ['applydoundosimplemove',['ApplyDoUndoSimpleMove',['../structosl_1_1effect_1_1ApplyDoUndoSimpleMove.html',1,'osl::effect']]],
  ['applydoundosimplemove_3c_20p_2c_20boardbiteffect_3c_20basestate_20_3e_20_3e',['ApplyDoUndoSimpleMove&lt; P, BoardBitEffect&lt; BaseState &gt; &gt;',['../structosl_1_1effect_1_1ApplyDoUndoSimpleMove_3_01P_00_01BoardBitEffect_3_01BaseState_01_4_01_4.html',1,'osl::effect']]],
  ['applydoundosimplemove_3c_20p_2c_20signatureeffect_3c_20basestate_20_3e_20_3e',['ApplyDoUndoSimpleMove&lt; P, SignatureEffect&lt; BaseState &gt; &gt;',['../structosl_1_1effect_1_1ApplyDoUndoSimpleMove_3_01P_00_01SignatureEffect_3_01BaseState_01_4_01_4.html',1,'osl::effect']]],
  ['array',['Array',['../structosl_1_1misc_1_1FixedCapacityVector_1_1Array.html',1,'osl::misc::FixedCapacityVector']]],
  ['atomiccounter',['AtomicCounter',['../classosl_1_1misc_1_1AtomicCounter.html',1,'osl::misc']]],
  ['attackdefencearoundking',['AttackDefenceAroundKing',['../structosl_1_1move__classifier_1_1AttackDefenceAroundKing.html',1,'osl::move_classifier']]],
  ['attackdefense',['AttackDefense',['../classosl_1_1eval_1_1endgame_1_1AttackDefense.html',1,'osl::eval::endgame']]],
  ['attackfromopposingsliders',['AttackFromOpposingSliders',['../classosl_1_1move__probability_1_1AttackFromOpposingSliders.html',1,'osl::move_probability']]],
  ['attackhelper',['AttackHelper',['../classosl_1_1ntesuki_1_1NtesukiSearcher_1_1AttackHelper.html',1,'osl::ntesuki::NtesukiSearcher']]],
  ['attackhelper',['AttackHelper',['../classosl_1_1ntesuki_1_1OracleProverLight_1_1AttackHelper.html',1,'osl::ntesuki::OracleProverLight']]],
  ['attackhelper',['AttackHelper',['../classOracleProverLight_1_1AttackHelper.html',1,'osl::ntesuki::OracleProverLight']]],
  ['attackhelperdisproof',['AttackHelperDisproof',['../classNtesukiSimulationSearcher_1_1AttackHelperDisproof.html',1,'osl::ntesuki::NtesukiSimulationSearcher']]],
  ['attackhelperdisproof',['AttackHelperDisproof',['../classosl_1_1ntesuki_1_1NtesukiSimulationSearcher_1_1AttackHelperDisproof.html',1,'osl::ntesuki::NtesukiSimulationSearcher']]],
  ['attackhelperproof',['AttackHelperProof',['../classosl_1_1ntesuki_1_1NtesukiSimulationSearcher_1_1AttackHelperProof.html',1,'osl::ntesuki::NtesukiSimulationSearcher']]],
  ['attackhelperproof',['AttackHelperProof',['../classNtesukiSimulationSearcher_1_1AttackHelperProof.html',1,'osl::ntesuki::NtesukiSimulationSearcher']]],
  ['attackking',['AttackKing',['../classosl_1_1eval_1_1endgame_1_1AttackKing.html',1,'osl::eval::endgame']]],
  ['attackking8',['AttackKing8',['../classosl_1_1rating_1_1AttackKing8.html',1,'osl::rating']]],
  ['attackking8group',['AttackKing8Group',['../structosl_1_1rating_1_1AttackKing8Group.html',1,'osl::rating']]],
  ['attackking8long',['AttackKing8Long',['../classosl_1_1move__probability_1_1AttackKing8Long.html',1,'osl::move_probability']]],
  ['attackmajorsinbase',['AttackMajorsInBase',['../classosl_1_1eval_1_1ml_1_1AttackMajorsInBase.html',1,'osl::eval::ml']]],
  ['attacktoopposingsliders',['AttackToOpposingSliders',['../classosl_1_1move__probability_1_1AttackToOpposingSliders.html',1,'osl::move_probability']]],
  ['attacktopinned',['AttackToPinned',['../classosl_1_1move__generator_1_1AttackToPinned.html',1,'osl::move_generator']]],
  ['average',['Average',['../classosl_1_1stat_1_1Average.html',1,'osl::stat']]]
];
